/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Angular Notch Filter\",\"required\":[\"angle\",\"range_mean\",\"ampl"
    "itude_mean\"],\"description\":\"Angular notch filter parameters for window"
    " glass echoes\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"ty"
    "pe\":\"object\",\"properties\":{\"range_mean\":{\"type\":\"array\",\"items\":{\"type"
    "\":\"number\"},\"description\":\"Mean range [m]\"},\"angle\":{\"type\":\"array\",\"i"
    "tems\":{\"type\":\"number\"},\"description\":\"Angle [deg]\"},\"amplitude_mean\":"
    "{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Mean "
    "amplitude [dB]\"}}}"
    ,
    /* example: */
    "{\"range_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0"
    ".068,0.0675,0.06475],\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,"
    "22.0,23.0,24.0],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,"
    "2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Atmospheric Parameters\",\"required\":[\"temperature\",\"pressure\""
    ",\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_velocity\",\"attenuation\",\"w"
    "avelength\"],\"description\":\"Atmospheric parameters\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"temper"
    "ature\":{\"type\":\"number\",\"description\":\"Temperature along measurement "
    "path "
    "[\\u00b0C]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength"
    " [nm]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) [m]\"}}}"
    ,
    /* example: */
    "{\"temperature\":7,\"pressure_sl\":970,\"wavelength\":1550,\"rel_humidity\":63"
    ",\"attenuation\":0.028125,\"pressure\":970,\"group_velocity\":299711000.0,\"a"
    "msl\":0}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Beam Geometry\",\"required\":[\"beam_exit_diameter\",\"beam_diverg"
    "ence\"],\"description\":\"Laser beam geometry details\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"beam_d"
    "ivergence\":{\"exclusiveMinimum\":false,\"minimum\":0,\"type\":\"number\",\"desc"
    "ription\":\"Beam divergence in far field [rad]\"},\"beam_exit_diameter\":{\""
    "exclusiveMinimum\":false,\"minimum\":0,\"type\":\"number\",\"description\":\"Bea"
    "m width at exit aperture [m]\"}}}"
    ,
    /* example: */
    "{\"beam_divergence\":0.0003,\"beam_exit_diameter\":0.0072}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Control Object Catalog\",\"definitions\":{\"common\":{\"properties"
    "\":{\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\",\"checkerboard2x2\",\"che"
    "vron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"],\""
    "description\":\"shape identifier\"},\"surface_type\":{\"type\":\"string\",\"enum"
    "\":[\"retro_reflective_foil\",\"diffuse\"],\"description\":\"surface material "
    "type\"},\"name\":{\"minLength\":3,\"type\":\"string\",\"description\":\"unique "
    "type identifier\"},\"description\":{\"type\":\"string\",\"description\":\"string"
    " describing the object\"}},\"type\":\"object\",\"required\":[\"name\",\"shape\"],"
    "\"description\":\"common object properties\"},\"chevron\":{\"allOf\":[{\"$ref\":"
    "\"#/definitions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\""
    ":[\"chevron\"],\"description\":\"shape identifier\"},\"thickness\":{\"exclusive"
    "Minimum\":true,\"minimum\":0,\"type\":\"number\",\"description\":\"thickness in "
    "meters\"},\"outside_edge_length\":{\"exclusiveMinimum\":true,\"minimum\":0,\"t"
    "ype\":\"number\",\"description\":\"length of the two outer edges in meters\"}"
    "},\"type\":\"object\",\"required\":[\"shape\",\"outside_edge_length\",\"thickness"
    "\"],\"description\":\"chevron specific properties\"}],\"type\":\"object\",\"desc"
    "ription\":\"chevron\"},\"round_corner_cube_prism\":{\"allOf\":[{\"$ref\":\"#/def"
    "initions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"rou"
    "nd_corner_cube_prism\"],\"description\":\"shape identifier\"},\"diameter\":{\""
    "exclusiveMinimum\":true,\"minimum\":0,\"type\":\"number\",\"description\":\"diam"
    "eter in meters\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"}},\"type\":\"object\",\"require"
    "d\":[\"shape\",\"diameter\"],\"description\":\"round corner cube prism "
    "specific properties\"}],\"type\":\"object\",\"description\":\"round corner "
    "cube prism\"},\"sphere\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"prop"
    "erties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"sphere\"],\"description\":\"sha"
    "pe identifier\"},\"diameter\":{\"exclusiveMinimum\":true,\"minimum\":0,\"type\""
    ":\"number\",\"description\":\"diameter in meters\"}},\"type\":\"object\",\"requir"
    "ed\":[\"shape\",\"diameter\"],\"description\":\"sphere specific properties\"}],"
    "\"type\":\"object\",\"description\":\"sphere\"},\"cylinder\":{\"allOf\":[{\"$ref\":\""
    "#/definitions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":"
    "[\"cylinder\"],\"description\":\"shape identifier\"},\"diameter\":{\"exclusiveM"
    "inimum\":true,\"minimum\":0,\"type\":\"number\",\"description\":\"diameter in me"
    "ters\"},\"height\":{\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\"number\",\""
    "description\":\"height in meters\"}},\"type\":\"object\",\"required\":[\"shape\","
    "\"diameter\",\"height\"],\"description\":\"cylinder specific properties\"}],\"t"
    "ype\":\"object\",\"description\":\"cylinder\"},\"rectangle\":{\"allOf\":[{\"$ref\":"
    "\"#/definitions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\""
    ":[\"rectangle\"]},\"length\":{\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\""
    "number\",\"description\":\"length in meters\"},\"width\":{\"exclusiveMinimum\":"
    "true,\"minimum\":0,\"type\":\"number\",\"description\":\"width in meters\"}},\"ty"
    "pe\":\"object\",\"required\":[\"shape\",\"length\",\"width\"],\"description\":\"rect"
    "angle specific properties\"}],\"type\":\"object\",\"description\":\"rectangle\""
    "},\"checkerboard2x2\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"proper"
    "ties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"checkerboard2x2\"],\"descriptio"
    "n\":\"shape identifier\"},\"square_length\":{\"exclusiveMinimum\":true,\"minim"
    "um\":0,\"type\":\"number\",\"description\":\"length of a square of the "
    "checkerboard in meters\"}},\"type\":\"object\",\"required\":[\"shape\",\"square_"
    "length\"],\"description\":\"checkerboard specific "
    "properties\"}],\"type\":\"object\",\"description\":\"checkerboard 2 by 2\"},\"ci"
    "rcular_disk\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{"
    "\"shape\":{\"type\":\"string\",\"enum\":[\"circular_disk\"],\"description\":\"shape"
    " identifier\"},\"diameter\":{\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\""
    "number\",\"description\":\"diameter in "
    "meters\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in meters, "
    "e.g. reflector constant (optional)\"}},\"type\":\"object\",\"required\":[\"sha"
    "pe\",\"diameter\"],\"description\":\"circular disk specific "
    "properties\"}],\"type\":\"object\",\"description\":\"circular "
    "disk\"}},\"required\":[\"types\"],\"description\":\"List of control object "
    "type definitions\",\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"properties\":{\"types\":{\"uniqueItems\":true,\"type\":\"array\",\"items\":{\"one"
    "Of\":[{\"$ref\":\"#/definitions/rectangle\"},{\"$ref\":\"#/definitions/checker"
    "board2x2\"},{\"$ref\":\"#/definitions/chevron\"},{\"$ref\":\"#/definitions/cir"
    "cular_disk\"},{\"$ref\":\"#/definitions/cylinder\"},{\"$ref\":\"#/definitions/"
    "sphere\"},{\"$ref\":\"#/definitions/round_corner_cube_prism\"}],\"type\":\"obj"
    "ect\"}}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"types\":[{\"shape\":\"rectangle\",\"width\":0.3,\"name\":\"Rectangle "
    "60x30\",\"length\":0.6,\"description\":\"Rectangle (60cm x "
    "30cm)\"},{\"shape\":\"rectangle\",\"width\":0.4,\"name\":\"Rectangle "
    "80x40\",\"length\":0.8,\"description\":\"Rectangle (80cm x 40cm)\"},{\"shape\":"
    "\"checkerboard2x2\",\"square_length\":0.3,\"name\":\"Checkerboard2x2 "
    "30\",\"description\":\"Checkerboard (square length: 30cm)\"},{\"shape\":\"chec"
    "kerboard2x2\",\"square_length\":0.5,\"name\":\"Checkerboard2x2 "
    "50\",\"description\":\"Checkerboard (square length: "
    "50cm)\"},{\"shape\":\"chevron\",\"thickness\":0.1016,\"name\":\"Chevron "
    "24''/4''\",\"outside_edge_length\":0.6096,\"description\":\"Chevron (a=24'';"
    " b=4'')\"},{\"shape\":\"circular_disk\",\"surface_type\":\"diffuse\",\"diameter\""
    ":0.5,\"name\":\"Circular Disk 50\",\"description\":\" Circular Disk "
    "(diameter: 50cm)\"},{\"shape\":\"circular_disk\",\"surface_type\":\"retro_refl"
    "ective_foil\",\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"diameter\":0.05,\"name\":\"RIEGL flat reflector 50"
    " mm\"},{\"shape\":\"circular_disk\",\"surface_type\":\"retro_reflective_foil\","
    "\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"diameter\":0.1,\"name\":\"RIEGL flat reflector 100"
    " mm\"},{\"shape\":\"circular_disk\",\"surface_type\":\"retro_reflective_foil\","
    "\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"diameter\":0.15,\"name\":\"RIEGL flat reflector "
    "150 mm\"},{\"shape\":\"cylinder\",\"surface_type\":\"retro_reflective_foil\",\"d"
    "escription\":\"cylindrical reflector from retro-reflective "
    "foil\",\"diameter\":0.05,\"name\":\"RIEGL cylindrical reflector 50 mm\",\"heig"
    "ht\":0.05},{\"shape\":\"cylinder\",\"surface_type\":\"retro_reflective_foil\",\""
    "description\":\"cylindrical reflector from retro-reflective "
    "foil\",\"diameter\":0.1,\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\",\"height\":0.1},{\"shape\":\"sphere\",\"diameter\":0.2,\"name\":\"Sphere 200 "
    "mm\",\"description\":\"Sphere (diameter: 200 mm)\"},{\"shape\":\"round_corner_"
    "cube_prism\",\"diameter\":0.05,\"offset\":0.0,\"name\":\"Corner Cube Prism 50 "
    "mm\",\"description\":\"round corner cube prism\"}],\"comments\":[\"This file "
    "contains a list of control object types (aka. 'catalog').\",\"Each type "
    "is described by an object,\",\"which must contain at least the following"
    " parameters:\",\"  - name: unique identifier of the type\",\"  - shape: "
    "one of the following supported shapes:\",\"      - rectangle\",\"      - "
    "checkerboard2x2\",\"      - chevron\",\"      - circular_disk\",\"      - "
    "cylinder\",\"      - sphere\",\"      - "
    "round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Control "
    "Object Reference file\",\"properties\":{\"reference_file\":{\"properties\":{\""
    "file_path\":{\"type\":\"string\",\"description\":\"Path of the control object "
    "file relative to referring "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"re"
    "quired\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference to a "
    "control object file\"}},\"type\":\"object\",\"description\":\"Details about "
    "the control object reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Detection Probability\",\"required\":[\"amplitude\",\"detection_pr"
    "obability\"],\"description\":\"Detection probability as a function of ampl"
    "itude\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"properties\":{\"detection_probability\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"},\"description\":\"Detection probability [0..1]\"},\"amplitud"
    "e\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Amplitude "
    "[dB]\"}}}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device Information\",\"required\":[\"device_type\",\"serial_number"
    "\"],\"description\":\"Details about the device used to acquire the point c"
    "loud\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obje"
    "ct\",\"properties\":{\"device_name\":{\"type\":\"string\",\"description\":\"Option"
    "al device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build variant\"},\"channel_number\":{\"exclusiveMinimum\":false,\"minimum\":0"
    ",\"type\":\"integer\",\"description\":\"Laser channel number (not defined or "
    "0: single channel device)\"}}}"
    ,
    /* example: */
    "{\"device_name\":\"Scanner 1\",\"channel_text\":\"\",\"device_type\":\"VZ-400i\",\""
    "serial_number\":\"S2221234\",\"device_build\":\"\",\"channel_number\":0}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device "
    "Geometry\",\"required\":[\"primary\"],\"description\":\"Scanner device "
    "geometry details\",\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"type\":\"object\",\"properties\":{\"primary\":{\"properties\":{\"ID\":{\"maxItems"
    "\":2,\"minItems\":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},\"descriptio"
    "n\":\"Structure identifier\"},\"content\":{\"type\":\"array\",\"items\":{\"type\":\""
    "number\"},\"description\":\"Internal calibration values\"}},\"type\":\"object\""
    ",\"required\":[\"ID\",\"content\"],\"description\":\"Primary device geometry "
    "structure (mandatory)\"},\"secondary\":{\"properties\":{\"ID\":{\"maxItems\":2,"
    "\"minItems\":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},\"description\":\""
    "Structure identifier\"},\"content\":{\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"},\"description\":\"Internal calibration values\"}},\"type\":\"object\",\"re"
    "quired\":[\"ID\",\"content\"],\"description\":\"Additional device geometry "
    "structure (optional)\"},\"amu\":{\"properties\":{\"frameCC\":{\"exclusiveMinim"
    "um\":false,\"minimum\":0,\"type\":\"number\",\"description\":\"Frame Circle "
    "Count (number of LSBs per full rotation about frame axis)\"},\"lineCC\":{"
    "\"exclusiveMinimum\":false,\"minimum\":0,\"type\":\"number\",\"description\":\"Li"
    "ne Circle Count (number of LSBs per full rotation about line "
    "axis)\"}},\"type\":\"object\",\"description\":\"Angle Measurement Unit\"}}}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[4,0],\"content\":[0]},\"secondary\":{\"ID\":[91,0],\"conten"
    "t\":[0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device Geometry Passive "
    "Channel\",\"required\":[\"primary\"],\"description\":\"Scanner passive channel"
    " device geometry details\",\"$schema\":\"http://json-schema.org/draft-04/s"
    "chema#\",\"type\":\"object\",\"properties\":{\"primary\":{\"properties\":{\"ID\":{\""
    "maxItems\":2,\"minItems\":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},\"de"
    "scription\":\"Structure identifier\"},\"content\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"},\"description\":\"Internal calibration values\"}},\"type\":"
    "\"object\",\"required\":[\"ID\",\"content\"],\"description\":\"Primary device "
    "geometry structure (mandatory)\"}}}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[143,0],\"content\":[0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Device "
    "Output Limits\",\"properties\":{\"range_minimum\":{\"type\":\"number\",\"descrip"
    "tion\":\"Minimum possible range in "
    "meters.\"},\"amplitude_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible amplitude in dB.\"},\"background_radiation_minimum\":{\"type\":\"nu"
    "mber\",\"description\":\"Minimum possible background radiation.\"},\"reflect"
    "ance_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible "
    "reflectance in "
    "dB.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"amplitude_maximum\":{\"type\":\"number\""
    ",\"description\":\"Maximum possible amplitude in dB.\"},\"background_radiat"
    "ion_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible "
    "background radiation.\"},\"reflectance_maximum\":{\"type\":\"number\",\"descri"
    "ption\":\"Maximum possible reflectance in "
    "dB.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible"
    " range in "
    "meters.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"},\"mta_zone_count_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum number of MTA "
    "zones.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\"}},\"type\":\"object\",\"description\":\"Limits of the measured values "
    "output by the device. The limits depend on the device type, "
    "measurement program and/or scan pattern.\"}"
    ,
    /* example: */
    "{\"range_minimum\":2.9,\"deviation_minimum\":-1,\"mta_zone_count_maximum\":7"
    ",\"amplitude_maximum\":100.0,\"background_radiation_minimum\":0,\"reflectan"
    "ce_maximum\":100.0,\"range_maximum\":10000.0,\"amplitude_minimum\":0.0,\"dev"
    "iation_maximum\":32767,\"reflectance_minimum\":-100.0,\"background_radiati"
    "on_maximum\":0}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Devices "
    "Information\",\"type\":\"array\",\"items\":{\"properties\":{\"device_name\":{\"typ"
    "e\":\"string\",\"description\":\"Optional device name (e.g. 'Scanner 1' for "
    "multi-scanner "
    "systems)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set "
    "when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build variant\"},\"channel_number\":{\"exclusiveMinimum\":false,\"minimum\":0"
    ",\"type\":\"integer\",\"description\":\"Laser channel number (not defined or "
    "0: single channel device)\"}},\"type\":\"object\",\"required\":[\"device_type\""
    ",\"serial_number\"]},\"description\":\"Details about the devices used to "
    "acquire the point cloud (e.g. when merging point clouds of different "
    "devices)\"}"
    ,
    /* example: */
    "[{\"device_name\":\"Scanner 1\",\"signed\":false,\"channel_text\":\"\",\"device_t"
    "ype\":\"VZ-400i\",\"serial_number\":\"S2221234\",\"device_build\":\"\",\"channel_n"
    "umber\":0},{\"device_name\":\"Scanner 2\",\"signed\":true,\"channel_text\":\"\",\""
    "device_type\":\"VQ-1560i-DW\",\"serial_number\":\"S2222680\",\"device_build\":\""
    "\",\"channel_number\":1},{\"device_name\":\"Scanner 3\",\"signed\":true,\"channe"
    "l_text\":\"\",\"device_type\":\"VQ-1560i-DW\",\"serial_number\":\"S2222680\",\"dev"
    "ice_build\":\"\",\"channel_number\":2}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Dyntrig\""
    ",\"properties\":{\"scale\":{\"type\":\"number\",\"description\":\"Scale in units "
    "of dB, for calculation of line: line number N=(amplitude-offset)/scale"
    "\"},\"tab\":{\"maxItems\":128,\"description\":\"...\",\"type\":\"array\",\"items\":{\""
    "properties\":{\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger "
    "threshold in units of "
    "dB\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of "
    "dB/m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold "
    "in units of dB\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of "
    "constant pre-trigger threshold elevation in units of "
    "m\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of m\"}},\"type\":\"object\",\"req"
    "uired\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"description\":\".."
    ".\"},\"minItems\":1},\"offset\":{\"type\":\"number\",\"description\":\"Offset in "
    "units of dB, for calculation of line\"},\"post\":{\"properties\":{\"a\":{\"max"
    "Items\":2080,\"description\":\"...\",\"type\":\"array\",\"items\":{\"type\":\"number"
    "\"},\"minItems\":1},\"nc\":{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"des"
    "cription\":\"Number of entries\"}},\"type\":\"object\",\"required\":[\"nc\",\"a\"],"
    "\"description\":\"Dyntrig post values\"},\"pre\":{\"properties\":{\"a\":{\"maxIte"
    "ms\":2080,\"description\":\"...\",\"type\":\"array\",\"items\":{\"type\":\"number\"},"
    "\"minItems\":1},\"nc\":{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"descri"
    "ption\":\"Number of entries\"}},\"type\":\"object\",\"required\":[\"nc\",\"a\"],\"de"
    "scription\":\"Dyntrig pre values\"}},\"description\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"scale\":1.0,\"tab\":[{\"thra2\":0.0,\"dec1\":0.0,\"dec2\":0.0,\"thra1\":0.0,\"de"
    "l2\":0.0,\"del1\":0.0}],\"offset\":0.0,\"post\":{\"a\":[78,86,126,134,31],\"nc\":"
    "128},\"pre\":{\"a\":[78,86,126,134,31],\"nc\":128}}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Echo "
    "Information\",\"required\":[\"echo_file\"],\"description\":\"Details about "
    "echo files\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\""
    ":\"object\",\"properties\":{\"echo_file\":{\"properties\":{\"file_extension\":{\""
    "type\":\"string\",\"description\":\"Echo file extension, without the leading"
    " dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"}},\"type\":\"object\",\"required\":[\"file_extension\"]}}}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_extension\":\"owp\",\"file_uuid\":\"26a03615-67c0-4bea-8"
    "fe8-c577378fe661\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Exponential Decomposition\",\"definitions\":{\"channel\":{\"proper"
    "ties\":{\"delay\":{\"type\":\"number\",\"description\":\"delay calibration in "
    "seconds\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude calibratio"
    "n\"},\"parameter\":{\"properties\":{\"A\":{\"type\":\"array\",\"items\":{\"type\":\"nu"
    "mber\"},\"description\":\"real part of amplitude factor in units of full-s"
    "cale\"},\"B\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"im"
    "aginary part of amplitude factor in units of full-scale\"},\"omega\":{\"ty"
    "pe\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"angular frequency"
    " in Hz\"},\"gamma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descriptio"
    "n\":\"decay in 1/second\"}},\"type\":\"object\",\"required\":[\"A\",\"B\",\"gamma\",\""
    "omega\"],\"description\":\"parameters of the syswave exponential sum\"},\"a_"
    "lin\":{\"exclusiveMaximum\":false,\"minimum\":0,\"exclusiveMinimum\":false,\"d"
    "escription\":\"relative linear amplitude range [0..1]\",\"type\":\"number\",\""
    "maximum\":1}},\"type\":\"object\",\"required\":[\"delay\",\"scale\",\"parameter\"]}"
    "},\"description\":\"Details for exponential decomposition of full "
    "waveform data\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"ad"
    "ditionalProperties\":false,\"type\":\"object\",\"patternProperties\":{\"^[0-9]"
    "+$\":{\"$ref\":\"#/definitions/channel\",\"description\":\"one field per "
    "channel, field name is channel index\"}}}"
    ,
    /* example: */
    "{\"0\":{\"delay\":3.783458418887631e-09,\"scale\":1.0,\"parameter\":{\"A\":[0.97"
    "72450923919678,0.3354335129261017,-1.312678575515747],\"B\":[-3.98130321"
    "50268555,0.08622030913829803,-0.3152860999107361],\"omega\":[352020896.0"
    ",3647927552.0,-1977987072.0],\"gamma\":[-1094726528.0,-769562752.0,-8480"
    "00064.0]},\"a_lin\":0.27},\"1\":{\"delay\":3.5e-09,\"scale\":1.0,\"parameter\":{"
    "\"A\":[0.9,0.3,-1.3],\"B\":[-3.9,0.0,-0.3],\"omega\":[352020896.0,3647927552"
    ".0,-1977987072.0],\"gamma\":[-1094726528.0,-769562752.0,-848000064.0]},\""
    "a_lin\":0.9}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Gaussian Decomposition\",\"required\":[\"amplitude_lsb_low_power"
    "\",\"amplitude_lsb_high_power\",\"amplitude_db\",\"range_offset_sec_low_powe"
    "r\",\"range_offset_sec_high_power\"],\"description\":\"riegl.gaussian_decomp"
    "osition contains information relevant for extracting calibrated "
    "amplitudes and calibrated ranges from a Gaussian decomposition of full"
    " waveform data. This information is contained in a table with five "
    "columns. Two columns are to be used as input: amplitude_lsb_low_power "
    "and amplitude_lsb_high_power. The other three columns provide the "
    "outputs. Amplitude_db gives the calibrated amplitude in the optical "
    "regime in decibels. The range offset columns provide additive range "
    "offsets, given in units of seconds, for each channel.\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"am"
    "plitude_lsb_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"ra"
    "nge_offset_sec_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\""
    "range_offset_sec_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}"
    "},\"amplitude_lsb_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}}"
    ",\"amplitude_db\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}}}}"
    ,
    /* example: */
    "{\"amplitude_lsb_high_power\":[],\"range_offset_sec_low_power\":[],\"range_"
    "offset_sec_high_power\":[],\"amplitude_lsb_low_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Geo Tag\""
    ",\"properties\":{\"crs\":{\"properties\":{\"epsg\":{\"minimum\":0,\"type\":\"intege"
    "r\",\"description\":\"EPSG "
    "code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate reference "
    "system name\"}},\"type\":\"object\",\"description\":\"Global Coordinate "
    "Reference System. Please note that only 3D Cartesian Coordinate "
    "Systems are allowed.\"},\"pose\":{\"maxItems\":4,\"minItems\":4,\"type\":\"array"
    "\",\"items\":{\"maxItems\":4,\"minItems\":4,\"type\":\"array\",\"items\":{\"type\":\"n"
    "umber\",\"description\":\"columns\"},\"description\":\"rows\"},\"description\":\"C"
    "oordinate Transformation Matrix to transform from File Coordinate "
    "System to Global Coordinate Reference System. 4x4 matrix stored as two"
    " dimensional array, row major "
    "order.\"}},\"type\":\"object\",\"description\":\"Point cloud georeferencing "
    "information\"}"
    ,
    /* example: */
    "{\"crs\":{\"epsg\":4978,\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\""
    ",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"703"
    "0\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.00000000000"
    "00000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000"
    "000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],A"
    "XIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 Geocentr"
    "ic\"},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"minimum\":0,\"excl"
    "usiveMinimum\":true,\"type\":\"number\",\"description\":\"Geometric scale "
    "factor applied to point coordinates\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Georefer"
    "encing Parameters\",\"properties\":{\"socs_to_rocs_matrix\":{\"maxItems\":4,\""
    "minItems\":4,\"type\":\"array\",\"items\":{\"maxItems\":4,\"minItems\":4,\"type\":\""
    "array\",\"items\":{\"type\":\"number\",\"description\":\"columns\"},\"description\""
    ":\"rows\"},\"description\":\"Coordinate Transformation Matrix to transform "
    "from Scanner's Own Coordinate System to Record Coordinate System. 4x4 "
    "matrix stored as two dimensional array, row major order.\"},\"socs_to_bo"
    "dy_matrix\":{\"maxItems\":4,\"minItems\":4,\"type\":\"array\",\"items\":{\"maxItem"
    "s\":4,\"minItems\":4,\"type\":\"array\",\"items\":{\"type\":\"number\",\"description"
    "\":\"columns\"},\"description\":\"rows\"},\"description\":\"Coordinate "
    "Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\"},\"trajectory_offsets\":{\"properties\":{\"offset"
    "_north\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_roll\":{\"type\":\"n"
    "umber\",\"description\":\"[deg]\"},\"offset_yaw\":{\"type\":\"number\",\"descripti"
    "on\":\"[deg]\"},\"offset_pitch\":{\"type\":\"number\",\"description\":\"[deg]\"},\"o"
    "ffset_time\":{\"type\":\"number\",\"description\":\"[s]\"},\"offset_height\":{\"ty"
    "pe\":\"number\",\"description\":\"[m]\"},\"version\":{\"type\":\"integer\",\"descrip"
    "tion\":\"Meaning of offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_east\":{\"type\":\"number\",\"description\":\"[m]\""
    "}},\"type\":\"object\",\"description\":\"Correction offsets applied to the "
    "trajectory data\"},\"body_coordinate_system_type\":{\"type\":\"string\",\"enum"
    "\":[\"NED\",\"ENU\"],\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: NED\"},\"trajectory_file\""
    ":{\"properties\":{\"file_extension\":{\"type\":\"string\",\"description\":\"Traje"
    "ctory file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\":[\"file_exte"
    "nsion\"],\"description\":\"Trajectory data used for georeferencing of the "
    "point cloud\"}},\"type\":\"object\",\"description\":\"Parameters used for "
    "georeferencing of the point cloud\"}"
    ,
    /* example: */
    "{\"body_coordinate_system_type\":\"NED\",\"socs_to_body_matrix\":[[-0.269827"
    "776749716,-0.723017716139738,0.635954678449952,0.0],[0.962908599449764"
    ",-0.20260517250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.750"
    "8684796801,0.0],[0.0,0.0,0.0,1.0]],\"trajectory_offsets\":{\"offset_north"
    "\":0.07,\"offset_roll\":0.03,\"offset_yaw\":-0.45,\"offset_pitch\":0.01,\"offs"
    "et_time\":18.007,\"offset_height\":-0.2,\"version\":0,\"offset_east\":0.15},\""
    "trajectory_file\":{\"file_extension\":\"pofx\",\"file_uuid\":\"93a03615-66c0-4"
    "bea-8ff8-c577378fe660\"}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Item Names\",\"description\":\"Map of item names\",\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"additionalProperties\":false,\"ty"
    "pe\":\"object\",\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"descr"
    "iption\":\"One field per item, field name is item id, field value is "
    "item name\"}}}"
    ,
    /* example: */
    "{\"2\":\"Name of item with id 2\",\"-1\":\"Name of item with id "
    "-1\",\"47\":\"Name of item with id 47\",\"1\":\"Name of item with id 1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Software License Keys\",\"description\":\"License keys for "
    "software features\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"additionalProperties\":false,\"type\":\"object\",\"patternProperties\":{\"^."
    "*$\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"string\",\"description"
    "\":\"License key (example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"},\"description\":\"Each field of the object represents a "
    "feature and holds a list of license keys, where the field name is the "
    "feature name.\"}}}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA "
    "- 8D2ED557\"],\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"MTA Sett"
    "ings\",\"properties\":{\"modulation_depth\":{\"minimum\":0,\"type\":\"number\",\"d"
    "escription\":\"Depth of pulse position modulation in meter.\"},\"zone_coun"
    "t\":{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\"Maximum "
    "number of MTA zones.\"},\"zone_width\":{\"minimum\":0,\"type\":\"number\",\"desc"
    "ription\":\"Width of a MTA zone in "
    "meter.\"}},\"type\":\"object\",\"description\":\"Parameters for MTA "
    "processing\"}"
    ,
    /* example: */
    "{\"modulation_depth\":9.368514,\"zone_count\":23,\"zone_width\":149.896225}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Near Range Correction "
    "Table\",\"required\":[\"delta\",\"content\"],\"description\":\"Lookup table for "
    "range correction based on raw range\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"delta\":{\"type\":\"numb"
    "er\",\"description\":\"Delta between table entries [m], first entry is at "
    "range = 0 m\"},\"content\":{\"maxItems\":2000,\"minItems\":1,\"type\":\"array\",\""
    "items\":{\"type\":\"number\"},\"description\":\"Correction value [m] to be "
    "added to the raw range\"}}}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Noise Estimates\",\"required\":[\"amplitude\",\"range_sigma\",\"ampl"
    "itude_sigma\"],\"description\":\"Standard deviation for range and "
    "amplitude as a function of amplitude\",\"$schema\":\"http://json-schema.or"
    "g/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"amplitude_sigma\":{\""
    "type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Sigma amplitude"
    " [dB]\"},\"range_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descr"
    "iption\":\"Sigma range [m]\"},\"amplitude\":{\"type\":\"array\",\"items\":{\"type\""
    ":\"number\"},\"description\":\"Amplitude [dB]\"}}}"
    ,
    /* example: */
    "{\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4"
    "32,0.39,0.354],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.02"
    "4,0.021,0.018,0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7."
    "0,8.0,9.0,10.0]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Notch Filter\",\"required\":[\"range_minimum\",\"range_maximum\",\"a"
    "mplitude_maximum\"],\"description\":\"Notch filter parameters for window "
    "glass echoes\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"typ"
    "e\":\"object\",\"properties\":{\"range_minimum\":{\"type\":\"number\",\"descriptio"
    "n\":\"Minimum range "
    "[m]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range [m"
    "]\"},\"amplitude_maximum\":{\"minimum\":0,\"type\":\"number\",\"description\":\"Ma"
    "ximum amplitude [dB]\"}}}"
    ,
    /* example: */
    "{\"range_minimum\":-0.5,\"range_maximum\":0.2,\"amplitude_maximum\":18.0}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pixel Information\",\"definitions\":{\"pixel_size\":{\"maxItems\":2"
    ",\"minItems\":2,\"type\":\"array\",\"items\":{\"minimum\":0,\"type\":\"number\",\"des"
    "cription\":\"Length of pixel edge [m].\"},\"description\":\"Size of "
    "pixels.\"}},\"required\":[\"size\"],\"description\":\"Details about the pixels"
    " contained in the file\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"properties\":{\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"de"
    "scription\":\"Size of pixels in a locally levelled cartesian coordinate "
    "system (xy). This is only used for pixels based on a map projection.\"}"
    ",\"size\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of "
    "pixels in file coordinate system.\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Plane Patch Matching\",\"definitions\":{\"file_reference\":{\"prop"
    "erties\":{\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane"
    " patch file relative to the match "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\""
    ":[\"file_uuid\",\"file_path\"],\"description\":\"Reference to a plane patch f"
    "ile\"}},\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"des"
    "cription\":\"Details about the plane patch matching process\",\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"properties\":{\"plane_patch_fi"
    "le_two\":{\"$ref\":\"#/definitions/file_reference\",\"description\":\"Referenc"
    "e to the plane patch file two\"},\"plane_patch_file_one\":{\"$ref\":\"#/defi"
    "nitions/file_reference\",\"description\":\"Reference to the plane patch "
    "file one\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d"
    "509-a64e-49ce-8b14-ff3130fbefa9\"},\"plane_patch_file_one\":{\"file_path\":"
    "\"Record009_Line001/191025_121410_Scanner_1.ptch\",\"file_uuid\":\"810f5d57"
    "-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Plane "
    "Patch Statistics\",\"properties\":{\"total_area\":{\"type\":\"number\",\"descrip"
    "tion\":\"sum of all plane patch areas [m\\u00b2]\"},\"total_horizontal_area"
    "\":{\"type\":\"number\",\"description\":\"sum of all plane patch areas "
    "projected to horizontal plane "
    "[m\\u00b2]\"}},\"type\":\"object\",\"description\":\"Statistics about plane "
    "patches found by plane patch extractor\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Plane Slope Class Info\",\"definitions\":{\"method-2\":{\"properti"
    "es\":{\"plane_classification_method\":{\"minimum\":2,\"type\":\"integer\",\"maxi"
    "mum\":2,\"description\":\"method ID (=2)\"},\"sloping_plane_classes_maximum_"
    "angle\":{\"minimum\":-360.0,\"type\":\"number\",\"maximum\":360.0,\"description\""
    ":\"maximum inclination angle of sloping plane patches [deg]\"},\"sloping_"
    "plane_classes_minimum_angle\":{\"minimum\":-360.0,\"type\":\"number\",\"maximu"
    "m\":360.0,\"description\":\"minimum inclination angle of sloping plane "
    "patches [deg]\"}},\"type\":\"object\",\"required\":[\"plane_classification_met"
    "hod\",\"sloping_plane_classes_minimum_angle\",\"sloping_plane_classes_maxi"
    "mum_angle\"],\"description\":\"Classification method 2\"},\"method-1\":{\"prop"
    "erties\":{\"plane_classification_method\":{\"minimum\":1,\"type\":\"integer\",\""
    "maximum\":1,\"description\":\"method ID (=1)\"},\"maximum_inclination_angle_"
    "horizontal\":{\"minimum\":-360.0,\"type\":\"number\",\"maximum\":360.0,\"descrip"
    "tion\":\"maximum inclination angle of horizontal plane patches [deg]\"}},"
    "\"type\":\"object\",\"required\":[\"plane_classification_method\",\"maximum_inc"
    "lination_angle_horizontal\"],\"description\":\"Classification method "
    "1\"}},\"required\":[\"settings\",\"classes\"],\"description\":\"Settings and "
    "classes for plane slope classification\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"properties\":{\"settings\":{\"oneOf\":[{\"$ref\":\"#/de"
    "finitions/method-1\"},{\"$ref\":\"#/definitions/method-2\"}],\"type\":\"object"
    "\",\"description\":\"Classification settings, details see documentation of"
    " rdbplanes\"},\"classes\":{\"additionalProperties\":false,\"type\":\"object\",\""
    "patternProperties\":{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"one "
    "field per class, field name is class number, field value is class "
    "name\"}},\"description\":\"Class definition table\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"settings\":{\"plane_classification_method\":2,\"sloping_plane_classes_ma"
    "ximum_angle\":70.0,\"sloping_plane_classes_minimum_angle\":10.0},\"classes"
    "\":{\"4\":\"sloping, pointing up and north\",\"12\":\"sloping, pointing down "
    "and north\",\"10\":\"sloping, pointing down and east\",\"9\":\"vertical, "
    "pointing west\",\"6\":\"vertical, pointing east\",\"5\":\"sloping, pointing up"
    " and west\",\"8\":\"vertical, pointing north\",\"7\":\"vertical, pointing "
    "south\",\"11\":\"sloping, pointing down and south\",\"2\":\"sloping, pointing "
    "up and east\",\"14\":\"horizontal, pointing down\",\"3\":\"sloping, pointing "
    "up and south\",\"1\":\"horizontal, pointing up\",\"13\":\"sloping, pointing "
    "down and west\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Point Attribute Groups\",\"description\":\"Grouping and sorting "
    "of point attributes for visualization purposes\",\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"additionalProperties\":false,\"type\":\"obj"
    "ect\",\"patternProperties\":{\"^.*$\":{\"minItems\":1,\"type\":\"array\",\"items\":"
    "{\"type\":\"string\",\"description\":\"Point attribute full name or name "
    "pattern (perl regular expression syntax)\"},\"description\":\"Each field "
    "of the object represents a point attribute group and holds a list of "
    "point attributes, where the field name is the group name.\"}}}"
    ,
    /* example: */
    "{\"Other Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Time\":[\"riegl."
    "timestamp\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Primary"
    " Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"]"
    ",\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Cloud Information\",\"properties\":{\"comments\":{\"type\":\"string\",\"descript"
    "ion\":\"Comments\"},\"project\":{\"type\":\"string\",\"description\":\"Project nam"
    "e\"},\"field_of_application\":{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"T"
    "LS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field of "
    "application\"}},\"type\":\"object\",\"description\":\"Details about point "
    "cloud files\"}"
    ,
    /* example: */
    "{\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\",\"field_of_application\":\"ALS\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pose "
    "Estimation\",\"required\":[\"orientation\"],\"description\":\"Estimated "
    "position and orientation information as measured by GNSS, IMU or "
    "inclination sensors\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"type\":\"object\",\"properties\":{\"barometric_height_amsl\":{\"type\":\"num"
    "ber\",\"description\":\"Altitude determined based on the atmospheric "
    "pressure according to the standard atmosphere laws [m].\"},\"orientation"
    "\":{\"properties\":{\"roll_accuracy\":{\"exclusiveMinimum\":true,\"minimum\":0,"
    "\"type\":\"number\",\"description\":\"Roll angle accuracy [deg]\"},\"pitch\":{\"m"
    "inimum\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Pitch angle "
    "about scanner Y-axis [deg]\"},\"yaw_accuracy\":{\"exclusiveMinimum\":true,\""
    "minimum\":0,\"type\":\"number\",\"description\":\"Yaw angle accuracy [deg]\"},\""
    "roll\":{\"minimum\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Rol"
    "l angle about scanner X-axis [deg]\"},\"pitch_accuracy\":{\"exclusiveMinim"
    "um\":true,\"minimum\":0,\"type\":\"number\",\"description\":\"Pitch angle "
    "accuracy [deg]\"},\"yaw\":{\"minimum\":-360,\"type\":\"number\",\"maximum\":360,\""
    "description\":\"Yaw angle about scanner Z-axis [deg]\"}},\"type\":\"object\","
    "\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw"
    "_accuracy\"],\"description\":\"Orientation values and orientation "
    "accuracies, measured with IMU or inclination sensors.\"},\"position\":{\"p"
    "roperties\":{\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate "
    "1 as defined by axis 1 of the specified CRS (e.g., X, "
    "Latitude)\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate "
    "3 as defined by axis 3 of the specified CRS (e.g., Z, Altitude)\"},\"ver"
    "tical_accuracy\":{\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\"number\",\""
    "description\":\"Vertical accuracy [m]\"},\"crs\":{\"properties\":{\"epsg\":{\"mi"
    "nimum\":0,\"type\":\"integer\",\"description\":\"EPSG "
    "code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"}},\"type\":\"object\",\"required\":[\"epsg\"],\"description\":\"Global "
    "Coordinate Reference "
    "System\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate 2 "
    "as defined by axis 2 of the specified CRS (e.g., Y, Longitude)\"},\"hori"
    "zontal_accuracy\":{\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\"number\","
    "\"description\":\"Horizontal accuracy [m]\"}},\"type\":\"object\",\"required\":["
    "\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"horizontal_accuracy\",\"ve"
    "rtical_accuracy\",\"crs\"],\"description\":\"Position coordinates and "
    "position accuracy values as measured by GNSS in the specified "
    "Coordinate Reference System (CRS)\"}}}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"orientation\":{\"roll_accur"
    "acy\":0.009433783936875745,\"pitch\":1.509153024827064,\"yaw_accuracy\":1.0"
    "094337839368757,\"roll\":3.14743073066123,\"pitch_accuracy\":0.00943378393"
    "6875745,\"yaw\":101.87293630292045},\"position\":{\"coordinate_1\":48.655799"
    "473,\"coordinate_3\":362.7124938964844,\"vertical_accuracy\":1.33149993419"
    "64722,\"crs\":{\"epsg\":4979,\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\""
    "WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\"
    "\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000"
    "000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.017453292"
    "51994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXI"
    "S[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\"},\"coordinate_2\":1"
    "5.645033406,\"horizontal_accuracy\":0.810699999332428}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pose Sensors\",\"definitions\":{\"vector\":{\"maxItems\":3,\"type\":\""
    "array\",\"items\":{\"type\":\"number\",\"description\":\"Index 0=X, 1=Y, 2=Z com"
    "ponent\"},\"minItems\":3}},\"required\":[\"gyroscope\",\"accelerometer\",\"magne"
    "tic_field_sensor\"],\"description\":\"Details on position and orientation "
    "sensors\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properti"
    "es\":{\"gyroscope\":{\"properties\":{\"unit\":{\"exclusiveMinimum\":true,\"minim"
    "um\":0,\"type\":\"number\",\"description\":\"Unit of raw data and calibration "
    "values, 1 LSB in rad/s\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"desc"
    "ription\":\"Sensitive Y axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement "
    "values\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Z axis of sensor at frame angle = 0\"}},\"type\":\"object\",\"required\":[\"u"
    "nit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlineari"
    "ty\"],\"description\":\"Gyroscope details\"},\"magnetic_field_sensor\":{\"prop"
    "erties\":{\"unit\":{\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\"number\",\""
    "description\":\"Unit of raw data and calibration values, 1 LSB in "
    "nT\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive "
    "Y axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"fixed\":{\"$ref\":\"#/definitio"
    "ns/vector\",\"description\":\"Distortion of magnetic field caused by "
    "non-rotating scanner part\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"d"
    "escription\":\"Sensitive X axis of sensor at frame angle = 0\"},\"relative"
    "_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative "
    "nonlinearity, dimensionless\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\","
    "\"description\":\"Sensitive Z axis of sensor at frame angle = 0\"}},\"type\""
    ":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixe"
    "d\",\"relative_nonlinearity\"],\"description\":\"Magnetic Field Sensor detai"
    "ls\"},\"accelerometer\":{\"properties\":{\"unit\":{\"exclusiveMinimum\":true,\"m"
    "inimum\":0,\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\"},\"y_axis\":{\"$ref\":\"#/defi"
    "nitions/vector\",\"description\":\"Sensitive Y axis of sensor at frame "
    "angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement "
    "values\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Z axis of sensor at frame angle = 0\"}},\"type\":\"object\",\"required\":[\"u"
    "nit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlineari"
    "ty\"],\"description\":\"Accelerometer details\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"gyroscope\":{\"unit\":0.00014544410805683583,\"y_axis\":[-0.4407659173011"
    "78,-0.7897399663925171,119.5894775390625],\"offset\":[-50.92609786987305"
    ",146.15643310546875,62.4327278137207],\"origin\":[0.026900000870227814,-"
    "0.03999999910593033,-0.08950000256299973],\"x_axis\":[-121.195556640625,"
    "0.8219714164733887,0.2313031703233719],\"relative_nonlinearity\":[2.8881"
    "76311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"z_axis\""
    ":[0.555869996547699,119.22135162353516,0.467585027217865]},\"magnetic_f"
    "ield_sensor\":{\"unit\":91.74311828613281,\"y_axis\":[0.0002788852143567055"
    "5,-0.011427424848079681,-5.204829722060822e-05],\"offset\":[-23812.05273"
    "4375,5606.57666015625,2493.28125],\"fixed\":[-1576.010498046875,1596.081"
    "787109375,0.0],\"x_axis\":[-0.011162743903696537,-2.315962774446234e-05,"
    "0.00016818844596855342],\"relative_nonlinearity\":[0.0,0.0,0.0],\"z_axis\""
    ":[0.00041987866279669106,7.876977906562388e-05,0.011407104320824146]},"
    "\"accelerometer\":{\"unit\":6.666666740784422e-05,\"y_axis\":[-7.02728891372"
    "6807,-44.12333679199219,14952.3701171875],\"offset\":[-733.3636474609375"
    ",58.969032287597656,1060.2550048828125],\"origin\":[0.026900000870227814"
    ",-0.03999999910593033,-0.08950000256299973],\"x_axis\":[-15008.123046875"
    ",56.956390380859375,-60.5175666809082],\"relative_nonlinearity\":[0.0,0."
    "0,0.0],\"z_axis\":[1.639882206916809,15166.744140625,-116.99742889404297"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pulse Position Modulation\",\"required\":[\"length\",\"num_mod_amp"
    "l\",\"pulse_interval\"],\"description\":\"Laser pulse position modulation "
    "used for MTA resolution\",\"$schema\":\"http://json-schema.org/draft-04/sc"
    "hema#\",\"type\":\"object\",\"properties\":{\"pulse_interval\":{\"type\":\"array\","
    "\"items\":{\"minimum\":0,\"type\":\"number\"},\"description\":\"Explicit table of"
    " the pulse position modulation used for MTA resolution. Table gives "
    "times between successive laser pulses in seconds.\"},\"num_mod_ampl\":{\"m"
    "inimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\"Number of "
    "different modulation amplitudes (2: binary modulation)\"},\"phase_step\":"
    "{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\"Step width "
    "in phase of modulation code from line to line\"},\"length\":{\"minimum\":0,"
    "\"type\":\"integer\",\"maximum\":255,\"description\":\"Length of code\"},\"code_p"
    "hase_mode\":{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\""
    "0: no synchronization, 1: toggle between 2 phases, 2: increment with "
    "phase_increment\"}}}"
    ,
    /* example: */
    "{\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06"
    ",2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2"
    ".759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0"
    "6],\"num_mod_ampl\":2,\"phase_step\":5,\"length\":31,\"code_phase_mode\":2}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Range Statistics\",\"required\":[\"minimum\",\"average\",\"maximum\","
    "\"std_dev\"],\"description\":\"Statistics about target distance wrt. SOCS o"
    "rigin\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"properties\":{\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"average\":{\"type\":\"number\",\"description\":\"Average value\"}}}"
    ,
    /* example: */
    "{\"minimum\":0.919,\"std_dev\":24.349,\"maximum\":574.35,\"average\":15.49738}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Receiver Internals\",\"definitions\":{\"fp_table_row\":{\"maxItems"
    "\":2048,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"minItems\":1},\"fp\":{\"p"
    "roperties\":{\"s\":{\"maxItems\":256,\"type\":\"array\",\"items\":{\"maxItems\":409"
    "6,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"minItems\":1},\"minItems\":1}"
    ",\"w\":{\"maxItems\":256,\"type\":\"array\",\"items\":{\"maxItems\":5,\"type\":\"arra"
    "y\",\"items\":{\"type\":\"number\"},\"minItems\":5},\"minItems\":1}},\"type\":\"obje"
    "ct\",\"required\":[\"s\",\"w\"],\"description\":\"Fingerprint values\"},\"fp_table"
    "\":{\"properties\":{\"ch\":{\"max\":255,\"description\":\"channel number\",\"type\""
    ":\"integer\",\"min\":0},\"ny\":{\"max\":2048,\"description\":\"number of y entrie"
    "s\",\"type\":\"integer\",\"min\":1},\"tc\":{\"max\":255,\"description\":\"table data"
    " type code\",\"type\":\"integer\",\"min\":0},\"tv\":{\"maxItems\":2048,\"type\":\"ar"
    "ray\",\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\""
    "number\"}]},\"minItems\":1},\"nx\":{\"max\":2048,\"description\":\"number of x e"
    "ntries\",\"type\":\"integer\",\"min\":1}},\"type\":\"object\",\"desription\":\"scann"
    "er internal "
    "data\",\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"]}},\"description\":\"Receiver "
    "Internals\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"proper"
    "ties\":{\"tbl\":{\"description\":\"various internal data\",\"type\":\"array\",\"it"
    "ems\":{\"$ref\":\"#/definitions/fp_table\"},\"minItems\":1},\"ns\":{\"minimum\":0"
    ",\"type\":\"integer\",\"maximum\":4095,\"description\":\"Number of samples\"},\"t"
    "\":{\"additionalProperties\":false,\"type\":\"object\",\"patternProperties\":{\""
    "^[0-9]+$\":{\"$ref\":\"#/definitions/fp\",\"description\":\"one field per "
    "channel, field name is channel index\"}}},\"nt\":{\"minimum\":0,\"type\":\"int"
    "eger\",\"maximum\":255,\"description\":\"Number of "
    "traces\"},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' "
    "instead\"},\"sr\":{\"minimum\":0,\"description\":\"Sample rate [Hz]\",\"type\":\"n"
    "umber\",\"exclusiveMinimum\":true},\"si\":{\"minimum\":0,\"type\":\"number\",\"max"
    "imum\":255,\"description\":\"Start index "
    "(hw_start)\"},\"mw\":{\"minimum\":0,\"description\":\"Maximum weight\",\"type\":\""
    "number\",\"maximum\":4095,\"exclusiveMinimum\":true},\"a\":{\"maxItems\":256,\"d"
    "escription\":\"Amplitude [dB]\",\"type\":\"array\",\"items\":{\"type\":\"number\"},"
    "\"minItems\":1}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"ns\":400,\"t\":{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,"
    "31],[78,86,126,134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,8"
    "6,126,134,31],[78,86,126,134,31]]}},\"nt\":128,\"tbl\":[{\"ch\":0,\"ny\":2,\"tc"
    "\":1,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],\"nx\":5}],\"sr\":7959997000."
    "0,\"si\":48,\"mw\":31,\"a\":[-1.55]}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Reflectance Calculation "
    "Table\",\"required\":[\"delta\",\"content\"],\"description\":\"Lookup table for "
    "reflectance calculation based on amplitude and range\",\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"del"
    "ta\":{\"type\":\"number\",\"description\":\"Delta between table entries [m], "
    "first entry is at range = 0 m\"},\"content\":{\"maxItems\":2000,\"minItems\":"
    "1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Correction "
    "value [dB] to be added to the amplitude\"}}}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Near-range reflectance correction\",\"required\":[\"ranges_m\",\"l"
    "ine_angles_deg\",\"reflectance_correction_db\"],\"description\":\"Range-depe"
    "ndent and scan-angle-dependent correction of reflectance reading\",\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"prope"
    "rties\":{\"line_angles_deg\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"d"
    "escription\":\"Angle [deg]\"},\"reflectance_correction_db\":{\"type\":\"array\""
    ",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"description\":\"colum"
    "ns (each value corresponds to an angle)\"},\"description\":\"rows (each "
    "array corresponds to a range)\"},\"description\":\"Near range reflectance "
    "correction in dB as a function of range over angle\"},\"ranges_m\":{\"type"
    "\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Range [m]\"}}}"
    ,
    /* example: */
    "{\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"reflecta"
    "nce_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0"
    ".7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1"
    ",0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Scan Pat"
    "tern\",\"definitions\":{\"program\":{\"properties\":{\"name\":{\"type\":\"string\","
    "\"description\":\"Name of measurement program\"},\"laser_prr\":{\"exclusiveMi"
    "nimum\":false,\"minimum\":0,\"type\":\"number\",\"description\":\"Laser Pulse "
    "Repetition Rate "
    "[Hz]\"}},\"type\":\"object\",\"required\":[\"name\"],\"description\":\"Measurement"
    " program\"}},\"properties\":{\"segments\":{\"properties\":{\"list\":{\"type\":\"ar"
    "ray\",\"items\":{\"properties\":{\"start\":{\"minimum\":0.0,\"type\":\"number\",\"ma"
    "ximum\":360.0,\"description\":\"Start angle in SOCS [deg]\"},\"stop\":{\"minim"
    "um\":0.0,\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop angle in "
    "SOCS [deg]\"},\"increment\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0"
    ",\"description\":\"Increment of angle in SOCS [deg]\"}},\"type\":\"object\",\"r"
    "equired\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line Scan Segment"
    "\"}},\"program\":{\"$ref\":\"#/definitions/program\"}},\"type\":\"object\",\"requi"
    "red\":[\"list\"],\"description\":\"Segmented Line Scan Pattern\"},\"rectangula"
    "r\":{\"properties\":{\"phi_stop\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":"
    "720.0,\"description\":\"Stop phi angle in SOCS [deg]\"},\"program\":{\"$ref\":"
    "\"#/definitions/program\"},\"theta_stop\":{\"minimum\":0.0,\"type\":\"number\",\""
    "maximum\":180.0,\"description\":\"Stop theta angle in SOCS [deg]\"},\"phi_in"
    "crement\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0,\"description\":\""
    "Increment of phi angle in SOCS [deg]\"},\"theta_increment\":{\"minimum\":0."
    "0,\"type\":\"number\",\"maximum\":90.0,\"description\":\"Increment of theta "
    "angle in SOCS [deg]\"},\"phi_start\":{\"minimum\":0.0,\"type\":\"number\",\"maxi"
    "mum\":360.0,\"description\":\"Start phi angle in SOCS [deg]\"},\"theta_start"
    "\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":180.0,\"description\":\"Start "
    "theta angle in SOCS [deg]\"}},\"type\":\"object\",\"required\":[\"phi_start\",\""
    "phi_stop\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta_increment\""
    "],\"description\":\"Rectangular Field Of View Scan Pattern\"},\"line\":{\"pro"
    "perties\":{\"start\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":360.0,\"desc"
    "ription\":\"Start angle in SOCS [deg]\"},\"program\":{\"$ref\":\"#/definitions"
    "/program\"},\"stop\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":720.0,\"desc"
    "ription\":\"Stop angle in SOCS [deg]\"},\"increment\":{\"minimum\":0.0,\"type\""
    ":\"number\",\"maximum\":90.0,\"description\":\"Increment of angle in SOCS [de"
    "g]\"}},\"type\":\"object\",\"required\":[\"start\",\"stop\",\"increment\"],\"descrip"
    "tion\":\"Line Scan Pattern\"}},\"description\":\"Scan pattern description\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_stop\":270.0,\"program\":{\"name\":\"High Speed\",\"laser"
    "_prr\":100000.0},\"theta_stop\":130.0,\"phi_increment\":0.04,\"theta_increme"
    "nt\":0.04,\"phi_start\":45.0,\"theta_start\":30.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Shot Inf"
    "ormation\",\"properties\":{\"shot_file\":{\"properties\":{\"file_extension\":{\""
    "type\":\"string\",\"description\":\"Shot file extension, without the leading"
    " dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\":[\"file_exte"
    "nsion\"]}},\"type\":\"object\",\"description\":\"Details about laser shot "
    "files\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_extension\":\"sodx\",\"file_uuid\":\"26a00815-67c0-4bff-"
    "8fe8-c577378fe663\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Stored "
    "filters\",\"required\":[\"activated\",\"filters\"],\"description\":\"Point "
    "filters applied in addition to the application-defined filters\",\"$sche"
    "ma\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"propert"
    "ies\":{\"filters\":{\"type\":\"array\",\"items\":{\"properties\":{\"title\":{\"type\""
    ":\"string\",\"description\":\"A short filter title (e.g. for display in a "
    "selection list)\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply "
    "('true') or ignore ('false') this "
    "filter\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter "
    "string to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a tooltip)\"}},\"type\":\"o"
    "bject\",\"required\":[\"activated\",\"title\",\"description\",\"filter\"],\"descri"
    "ption\":\"Point filter definition\"},\"description\":\"List of point "
    "filters\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') "
    "or ignore ('false') all filters\"}}}"
    ,
    /* example: */
    "{\"filters\":[{\"title\":\"Ignore uncertain points from MTA "
    "resolution\",\"activated\":false,\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"description\":\"Ignore points with uncertain MTA zone "
    "assignment\"},{\"title\":\"Ignore points below dynamic trigger "
    "level\",\"activated\":false,\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\"},{\"title\":\"Ignore points outside outer "
    "AABB\",\"activated\":false,\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\"},{\"title\":\"Ignore points inside inner "
    "AABB\",\"activated\":false,\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\"}],\"activated\":true}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"System Description\",\"required\":[\"$class\",\"version\",\"author\","
    "\"timestamp\",\"system\"],\"description\":\"Details of major system "
    "components like lidar sensors, cameras and navigation devices\",\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"properti"
    "es\":{\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time of "
    "creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"author\":{\"type\":\"string\","
    "\"description\":\"Name of the author that created the document\"},\"$class\""
    ":{\"type\":\"string\",\"enum\":[\"Document\"],\"description\":\"Object class "
    "name\"},\"version\":{\"type\":\"string\",\"description\":\"Document format "
    "version\"},\"system\":{\"type\":\"object\",\"description\":\"The actual system "
    "description, details see documentation of RIEGL System Description\"}}}"
    ,
    /* example: */
    "{\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"author\":\"RIEGL LMS GmbH, Aus"
    "tria\",\"$class\":\"Document\",\"version\":\"1.2.1\",\"system\":{\"details\":\"see "
    "documentation of RIEGL System Description\"}}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Temperature Calculation Table\",\"definitions\":{\"conversion_ta"
    "ble\":{\"properties\":{\"temperature\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"},\"description\":\"Temperature [\\u00b0C]\"},\"value\":{\"type\":\"array\",\""
    "items\":{\"type\":\"number\"},\"description\":\"LSB [1]\"}},\"type\":\"object\",\"re"
    "quired\":[\"value\",\"temperature\"]}},\"description\":\"Conversion of "
    "background radiation raw values to temperatures in \\u00b0C\",\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"Si\":{\"$ref\":\""
    "#/definitions/conversion_table\",\"description\":\"Conversion table for Si"
    " channel\"},\"InGaAs\":{\"$ref\":\"#/definitions/conversion_table\",\"descript"
    "ion\":\"Conversion table for InGaAs channel\"},\"InGaAs_Si_Difference\":{\"$"
    "ref\":\"#/definitions/conversion_table\",\"description\":\"Conversion table "
    "for InGaAs - Si difference\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"Si\":{\"temperature\":[546.300048828125,548.8164051212026,551.314393850"
    "0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299"
    "86177,564.4104671126105,567.0002936624203],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "\":{\"temperature\":[307.22196722535614,309.1153478247277,311.11880869150"
    "47,313.10025350480055,315.2137946389828,317.2172555057597,319.22071637"
    "25366,321.2021611858325,323.3157023200148],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "_Si_Difference\":{\"temperature\":[1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,"
    "1744.7813348796044,1681.9971312601092,1622.3944822534868],\"value\":[100"
    "0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036"
    "774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0"
    "411999877924]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Time Base\",\"required\":[\"epoch\",\"source\"],\"description\":\"Base"
    " of timestamps (epoch)\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"type\":\"object\",\"properties\":{\"system\":{\"type\":\"string\",\"enum\":["
    "\"unknown\",\"UTC\",\"GPS\"],\"description\":\"Time system (time "
    "standard)\"},\"epoch\":{\"type\":\"string\",\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)"
    ".\"},\"source\":{\"type\":\"string\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"descrip"
    "tion\":\"Timestamp source\"}}}"
    ,
    /* example: */
    "{\"system\":\"UTC\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Trajectory Information\",\"required\":[\"time_interval\",\"navigat"
    "ion_frame\"],\"description\":\"Details about position+orientation files\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"pr"
    "operties\":{\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. city/state/country\"},\"device\":{\"type\":\"string\",\"descrip"
    "tion\":\"Navigation device, e.g. "
    "name/type/serial\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"company\":{\"type\":\"string\",\"description\":\"Company name\"},\"time_"
    "interval\":{\"properties\":{\"minimum\":{\"type\":\"number\",\"description\":\"Min"
    "imum time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals [s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time"
    " interval [s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time"
    " interval [s]\"}},\"type\":\"object\",\"required\":[\"minimum\",\"average\",\"maxi"
    "mum\",\"std_dev\"],\"description\":\"Time interval "
    "statistics\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings used "
    "to calculate the trajectory (descriptive "
    "text)\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the file)\"},\"navigation_frame\":{\"type\":\"stri"
    "ng\",\"enum\":[\"unknown\",\"NED\",\"ENU\"],\"description\":\"Navigation frame "
    "(NED: North-East-Down, ENU: East-North-Up)\"},\"field_of_application\":{\""
    "type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\""
    "BLS\",\"ILS\"],\"description\":\"Field of application\"}}}"
    ,
    /* example: */
    "{\"location\":\"Horn\",\"device\":\"IMU Model 12/1, Serial# "
    "12345\",\"project\":\"Campaign 3\",\"company\":\"RIEGL LMS\",\"time_interval\":{\""
    "minimum\":0.00500032,\"std_dev\":5.51e-07,\"maximum\":0.005004883,\"average\""
    ":0.00500053},\"settings\":\"default\",\"software\":\"Navigation Software "
    "XYZ\",\"navigation_frame\":\"NED\",\"field_of_application\":\"MLS\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"TTIP Configuration\",\"required\":[\"ttip_version\",\"num_channel\""
    ",\"ext_channel\",\"ext_signal\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\""
    ",\"dmi_incr\",\"dmi_min_time\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel"
    "\",\"output_descr\",\"input_descr\",\"output_usage\",\"input_usage\",\"out_polar"
    "ity\",\"out_duration\",\"out_interval\",\"out_delay\",\"out_num_pulses\",\"in_po"
    "larity\",\"in_min_duration\",\"in_max_duration\",\"in_max_delay\"],\"descripti"
    "on\":\"Trigger-Timestamping-Unit/IP configuration\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"in_polar"
    "ity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .. positive edge, "
    "1 .. negative "
    "edge\"},\"ext_channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates none\"},\"ext_bi"
    "tmask\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"defines which of "
    "the internal pulse generators are to be started\"},\"ttip_version\":{\"min"
    "imum\":0,\"type\":\"integer\",\"description\":\"following main.sub.ss.sss\"},\"o"
    "ut_interval\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"output pulse"
    " interval [0.1 "
    "msec]\"},\"input_usage\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. deactivated, 1 .. just detecting and timestamping\"},\"out_polarity\":"
    "{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .. positive edge, 1 .. "
    "negative "
    "edge\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive strin"
    "g\"},\"out_duration\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"output"
    " pulse duration [0.1 msec]\"},\"in_max_duration\":{\"minimum\":0,\"type\":\"in"
    "teger\",\"description\":\"stops measurement of pulse duration of input "
    "signal [0.1 msec]\"},\"dmi_max_time\":{\"minimum\":0,\"type\":\"integer\",\"desc"
    "ription\":\"dmi, maximum time interval between trigger events [0.1 msec]"
    "\"},\"ext_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"external "
    "trigger, time delay [0.1 msec]\"},\"out_delay\":{\"minimum\":0,\"type\":\"inte"
    "ger\",\"description\":\"output pulse initial delay after start [0.1 msec]\""
    "},\"in_min_duration\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"input"
    " signals with smaller pulse durations are ignored [0.1 "
    "msec]\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment in "
    "ticks\"},\"in_max_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ma"
    "ximum delay to output pulse before fake event is generated [0.1 msec],"
    " zero indicates that no fake events are "
    "generated\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative "
    "[m]\"},\"dmi_min_time\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"dmi,"
    " minimum time interval between trigger events [0.1 "
    "msec]\"},\"ext_signal\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .."
    " use input signal, 1 .. use output signal of "
    "channel\"},\"channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID of"
    " input/output channel\"},\"output_usage\":{\"minimum\":0,\"type\":\"integer\",\""
    "description\":\"0 .. no output, 1 .. output derived from internal clock,"
    " 2 .. output derived from dmi, 3 .. output derived from external "
    "signal, 4 .. output static low, 5 .. output static high\"},\"ext_subdivi"
    "der\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"reduces the "
    "frequency, default "
    "1\"},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive string\""
    "},\"num_channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"number of"
    " input/output channels\"},\"out_num_pulses\":{\"minimum\":0,\"type\":\"integer"
    "\",\"description\":\"number of output pulses to be generated, 0 .. "
    "infinite\"}}}"
    ,
    /* example: */
    "{\"in_polarity\":0,\"ext_channel\":32,\"ext_bitmask\":0,\"ttip_version\":1,\"ou"
    "t_interval\":10000,\"input_usage\":1,\"out_polarity\":0,\"input_descr\":\"Port"
    " 1 - Exposure\",\"out_duration\":300,\"in_max_duration\":10000,\"dmi_max_tim"
    "e\":0,\"ext_delay\":0,\"out_delay\":0,\"in_min_duration\":0,\"dmi_incr\":0,\"in_"
    "max_delay\":9990,\"dmi_dist_per_tick\":0.0,\"dmi_min_time\":0,\"ext_signal\":"
    "0,\"channel\":0,\"output_usage\":1,\"ext_subdivider\":1,\"output_descr\":\"Port"
    " 1 - Trigger\",\"num_channel\":9,\"out_num_pulses\":1}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Vertex I"
    "nformation\",\"properties\":{\"vertex_file\":{\"properties\":{\"file_extension"
    "\":{\"type\":\"string\",\"description\":\"Vertex file extension, without the "
    "leading dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\""
    ":[\"file_extension\"]}},\"type\":\"object\",\"description\":\"Details about "
    "vertex file\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_extension\":\"vtx\",\"file_uuid\":\"51534d95-d71f-4f36"
    "-ae1a-3e63a21fd1c7\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Voxel Information\",\"oneOf\":[{\"additionalProperties\":false,\"p"
    "roperties\":{\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size\":{\""
    "oneOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/vox"
    "el_size_cubic\"}],\"description\":\"Size of voxels in file coordinate syst"
    "em.\"},\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\"},\"shape"
    "_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"}},\"required\":[\"s"
    "ize\",\"voxel_origin\",\"voxel_type\"]},{\"additionalProperties\":false,\"prop"
    "erties\":{\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size_llcs\":"
    "{\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size of voxels in a "
    "locally levelled cartesian coordinate system (xyz). This is only used "
    "for voxels based on a map projection.\"},\"voxel_origin\":{\"oneOf\":[{\"$re"
    "f\":\"#/definitions/voxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel_ori"
    "gin_point\",\"description\":\"The base point of the voxel grid. Used "
    "together with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute "
    "actual point coordinates.\"}]},\"size\":{\"$ref\":\"#/definitions/voxel_size"
    "\",\"description\":\"Size of voxels in file coordinate system.\"},\"shape_th"
    "resholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"reference_point\":"
    "{\"maxItems\":2,\"minItems\":2,\"type\":\"array\",\"items\":{\"minimum\":-180,\"typ"
    "e\":\"number\",\"maximum\":180},\"description\":\"Point in WGS84 geodetic "
    "decimal degree (EPSG:4326) that was used to compute the projection "
    "distortion parameters. The coefficient order is latitude, longitude. "
    "Only voxels with corresponding geo_tag, voxel_size and reference_point"
    " can be reliably processed together. This entry is available for voxel"
    " files in projected CRS only.\"}},\"required\":[\"reference_point\",\"size_l"
    "lcs\",\"size\",\"voxel_origin\",\"voxel_type\"]}],\"description\":\"Details "
    "about the voxels contained in the file\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"type\":\"object\",\"definitions\":{\"voxel_size_cubic"
    "\":{\"$ref\":\"#/definitions/edge_length\",\"type\":\"number\"},\"voxel_origin_e"
    "num\":{\"default\":\"corner\",\"enum\":[\"center\",\"corner\"],\"description\":\"Def"
    "ines whether the voxel's center or a corner is placed on CRS origin <t"
    "t>(0/0/0)</tt>.\"},\"voxel_size\":{\"maxItems\":3,\"minItems\":3,\"type\":\"arra"
    "y\",\"items\":{\"$ref\":\"#/definitions/edge_length\"},\"description\":\"Size of"
    " voxels.\"},\"shape_thresholds\":{\"properties\":{\"line\":{\"exclusiveMinimum"
    "\":true,\"minimum\":1,\"type\":\"number\",\"description\":\"If the biggest "
    "eigenvalue is bigger than the median eigenvalue * line_threshold, the "
    "voxel is considered a line.\"},\"plane\":{\"exclusiveMaximum\":true,\"minimu"
    "m\":0,\"exclusiveMinimum\":true,\"description\":\"If the smallest eigenvalue"
    " is smaller than the median eigenvalue * plane_threshold, the voxel is"
    " considered a plane.\",\"type\":\"number\",\"maximum\":1}},\"type\":\"object\",\"r"
    "equired\":[\"plane\",\"line\"],\"description\":\"Thresholds used to compute "
    "the voxel's shape_id value.\"},\"voxel_type\":{\"default\":\"centroid\",\"enum"
    "\":[\"center\",\"centroid\",\"index\"],\"description\":\"Whether a point in a "
    "voxel represents its center or its centroid. If type is <tt>index</tt>"
    " there is no point but only an integer voxel index.\"},\"edge_length\":{\""
    "exclusiveMinimum\":true,\"minimum\":0,\"type\":\"number\",\"description\":\"Leng"
    "th of voxel edge [m].\"},\"voxel_origin_point\":{\"maxItems\":3,\"minItems\":"
    "3,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Origin point"
    " for all voxel indices in voxel CRS.\"}}}"
    ,
    /* example: */
    "{\"voxel_type\":\"centroid\",\"size_llcs\":[0.5156575252891171,0.51308353566"
    "83303,0.5143705304787237],\"voxel_origin\":\"corner\",\"shape_thresholds\":{"
    "\"line\":6,\"plane\":0.16},\"size\":[0.5971642834779395,0.5971642834779395,0"
    ".5143705304787237],\"reference_point\":[48,16]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Waveform Averaging "
    "Settings\",\"required\":[\"num_shots\",\"mta_zone\"],\"description\":\"Settings "
    "for waveform averaging\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"type\":\"object\",\"properties\":{\"trim\":{\"minimum\":0,\"type\":\"number"
    "\",\"default\":0,\"maximum\":0.5,\"description\":\"Percentage for robust avera"
    "ging.\"},\"mta_zone\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Fixed "
    "MTA zone for averaging.\"},\"num_shots\":{\"minimum\":1,\"type\":\"integer\",\"d"
    "escription\":\"Number of consecutive shots to be used for averaging.\"}}}"
    ,
    /* example: */
    "{\"trim\":0.05,\"mta_zone\":1,\"num_shots\":7}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Waveform Information\",\"required\":[\"sample_block_file\",\"sampl"
    "e_data_files\"],\"description\":\"Details about waveform files\",\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"sample_block_"
    "file\":{\"properties\":{\"file_extension\":{\"type\":\"string\",\"description\":\""
    "Sample block file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\":[\"file_exte"
    "nsion\"]},\"range_offset_waveform_samples_m\":{\"type\":\"number\",\"descripti"
    "on\":\"Calibrated device specific range offset for waveform samples in m"
    "eters.\"},\"sample_data_files\":{\"type\":\"array\",\"items\":{\"properties\":{\"f"
    "ile_extension\":{\"type\":\"string\",\"description\":\"Sample data file "
    "extension, without the leading "
    "dot\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\"},\"sample_bits\":{\"exclusiveMa"
    "ximum\":false,\"minimum\":0,\"description\":\"Bitwidth of samples (e.g. 10 "
    "bit, 12 bit)\",\"exclusiveMinimum\":false,\"type\":\"integer\",\"maximum\":32},"
    "\"laser_wavelength\":{\"exclusiveMinimum\":false,\"minimum\":0,\"type\":\"numbe"
    "r\",\"description\":\"Laser wavelength in meters (0 = unknown)\"},\"channel\""
    ":{\"exclusiveMaximum\":false,\"minimum\":0,\"description\":\"Sample block "
    "channel number (255 = invalid)\",\"exclusiveMinimum\":false,\"type\":\"integ"
    "er\",\"maximum\":255},\"sample_interval\":{\"exclusiveMinimum\":false,\"minimu"
    "m\":0,\"type\":\"number\",\"description\":\"Sampling interval in seconds\"},\"de"
    "lta_st\":{\"type\":\"number\",\"description\":\"reserved\"}},\"type\":\"object\",\"r"
    "equired\":[\"channel\",\"channel_name\",\"sample_interval\",\"sample_bits\",\"la"
    "ser_wavelength\",\"delta_st\",\"file_extension\"]}},\"range_offset_m\":{\"type"
    "\":\"number\",\"description\":\"Calibrated device specific range offset for "
    "waveform analysis by system response fitting in "
    "meters.\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"sample_block_file\":{\"file_extension\":\"sbx\",\"file_uuid\":\"93a03615-66c"
    "0-4bea-8ff8-c577378fe660\"},\"sample_data_files\":[{\"delta_st\":0,\"channel"
    "_name\":\"high_power\",\"sample_bits\":12,\"file_uuid\":\"da084413-e3e8-4655-a"
    "122-071de8490d8e\",\"laser_wavelength\":0,\"channel\":0,\"file_extension\":\"s"
    "p0\",\"sample_interval\":1.00503e-09},{\"delta_st\":0,\"channel_name\":\"low_p"
    "ower\",\"sample_bits\":12,\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642"
    "d2\",\"laser_wavelength\":0,\"channel\":1,\"file_extension\":\"sp1\",\"sample_in"
    "terval\":1.00503e-09},{\"delta_st\":0,\"channel_name\":\"wwf\",\"sample_bits\":"
    "12,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"laser_wavelengt"
    "h\":0,\"channel\":5,\"file_extension\":\"sp5\",\"sample_interval\":1.00503e-09}"
    "],\"range_offset_waveform_samples_m \":7.283,\"range_offset_m\":3.1415}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Waveform"
    " Settings\",\"type\":\"array\",\"items\":{\"properties\":{\"pass_dev_greater\":{\""
    "type\":\"integer\",\"description\":\"Threshold for deviation greater than "
    "[1]\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range greater than "
    "[m]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform"
    " output "
    "enabled\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation less than "
    "[1]\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample block,"
    " e.g.: wfm, wwf\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform "
    "output "
    "enabled\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range less than "
    "[m]\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, "
    "...\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than [dB]\"}},\"type\":\"object\",\"required\":[\"sbl_na"
    "me\",\"enabled\",\"channel_idx_mask\"]},\"description\":\"Scanner settings for"
    " waveform output\"}"
    ,
    /* example: */
    "[{\"pass_rng_greater\":9.27,\"pass_ampl_less\":5.0,\"smart_enabled\":true,\"s"
    "bl_name\":\"wfm\",\"enabled\":true,\"pass_rng_less\":13.11,\"channel_idx_mask\""
    ":11,\"pass_ampl_greater\":1.0},{\"sbl_name\":\"wwf\",\"enabled\":false,\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Window Analysis\",\"required\":[\"result\",\"filter\",\"settings\"],\""
    "description\":\"Window analysis data estimated from scandata and "
    "resulting filter parameters\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"type\":\"object\",\"properties\":{\"result\":{\"properties\":{\"time"
    "stamp\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[s]\"},"
    "\"amplitude_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descripti"
    "on\":\"[dB]\"},\"amplitude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}"
    ",\"description\":\"[dB]\"},\"amplitude_offset\":{\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"[dB]\"},\"range_mean\":{\"type\":\"array\",\"item"
    "s\":{\"type\":\"number\"},\"description\":\"[m]\"},\"range_sigma\":{\"type\":\"array"
    "\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"},\"angle\":{\"type\":\"arra"
    "y\",\"items\":{\"type\":\"number\"},\"description\":\"[deg]\"}},\"type\":\"object\",\""
    "required\":[\"angle\",\"range_mean\",\"range_sigma\",\"amplitude_mean\",\"amplit"
    "ude_sigma\",\"amplitude_offset\"]},\"settings\":{\"properties\":{\"range\":{\"pr"
    "operties\":{\"sigma_factor\":{\"type\":\"number\"},\"additive_value\":{\"type\":\""
    "number\"}},\"type\":\"object\",\"required\":[\"sigma_factor\",\"additive_value\"]"
    "},\"amplitude\":{\"properties\":{\"sigma_factor\":{\"type\":\"number\"},\"additiv"
    "e_value\":{\"type\":\"number\"}},\"type\":\"object\",\"required\":[\"sigma_factor\""
    ",\"additive_value\"]}},\"type\":\"object\",\"required\":[\"range\",\"amplitude\"]}"
    ",\"filter\":{\"properties\":{\"range_max\":{\"type\":\"array\",\"items\":{\"type\":\""
    "number\"},\"description\":\"[m]\"},\"range_min\":{\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"[m]\"},\"angle\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"},\"description\":\"[deg]\"},\"amplitude_max\":{\"type\":\"array\","
    "\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"}},\"type\":\"object\",\"requ"
    "ired\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"]}}}"
    ,
    /* example: */
    "{\"result\":{\"timestamp\":[408.4441,411.4443],\"amplitude_sigma\":[0.427284"
    "4,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141,0.4373984,0.447279"
    "8,0.4346001,0.4345487,0.4540681],\"amplitude_mean\":[5.347396,5.263155,5"
    ".224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.007885,5.002441"
    ",4.982],\"amplitude_offset\":[1.9,1.9],\"range_mean\":[0.1105621,0.1079564"
    ",0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,"
    "0.1058445,0.1031261],\"range_sigma\":[0.01869652,0.02151435,0.01747969,0"
    ".01918765,0.01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.018"
    "99122,0.02009433],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15."
    "7,15.8,15.9]},\"settings\":{\"range\":{\"sigma_factor\":8,\"additive_value\":0"
    ".1},\"amplitude\":{\"sigma_factor\":4,\"additive_value\":1.0}},\"filter\":{\"ra"
    "nge_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.431,0"
    ".432],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0."
    "221,-0.223,-0.225,-0.227],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,"
    "15.6,15.7,15.8,15.9],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.8"
    "8,7.85,7.83,7.8,7.78]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Window Echo Correction\",\"required\":[\"amplitude\",\"range\",\"sli"
    "ces\"],\"description\":\"Correction parameters for window glass echoes\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"pro"
    "perties\":{\"slices\":{\"type\":\"array\",\"items\":{\"properties\":{\"table\":{\"mi"
    "nItems\":1,\"type\":\"array\",\"items\":{\"minItems\":1,\"type\":\"array\",\"items\":"
    "{\"maxItems\":3,\"minItems\":3,\"type\":\"array\",\"items\":{\"type\":\"number\",\"de"
    "scription\":\"Table cell (item 0: amplitude in dB, 1: range in m, 2: "
    "flags)\"},\"description\":\"Table column (= range "
    "axis)\"},\"description\":\"Table row (= amplitude "
    "axis)\"},\"description\":\"Correction table (dimension defined by the "
    "'amplitude' and 'range' "
    "objects)\"},\"amplitude\":{\"type\":\"number\",\"description\":\"Window echo "
    "amplitude of slice in dB\"}},\"type\":\"object\",\"required\":[\"amplitude\",\"t"
    "able\"],\"description\":\"Window echo correction parameter slice\"}},\"range"
    "\":{\"properties\":{\"minimum\":{\"minimum\":-2.0,\"type\":\"number\",\"maximum\":2"
    ".0,\"description\":\"Minimum range in m\"},\"maximum\":{\"minimum\":-2.0,\"type"
    "\":\"number\",\"maximum\":2.0,\"description\":\"Maximum range in "
    "m\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "range entries\"}},\"type\":\"object\",\"required\":[\"minimum\",\"maximum\",\"entr"
    "ies\"],\"description\":\"Range axis of correction table\"},\"amplitude\":{\"pr"
    "operties\":{\"minimum\":{\"minimum\":0.0,\"type\":\"number\",\"description\":\"Min"
    "imum amplitude in "
    "dB\"},\"maximum\":{\"minimum\":0.0,\"type\":\"number\",\"description\":\"Maximum "
    "amplitude in "
    "dB\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "amplitude entries\"}},\"type\":\"object\",\"required\":[\"minimum\",\"maximum\",\""
    "entries\"],\"description\":\"Amplitude axis of correction table\"}}}"
    ,
    /* example: */
    "{\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\""
    ":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}"
    "],\"range\":{\"minimum\":-1.5060822940732335,\"maximum\":1.5060822940732335,"
    "\"entries\":128},\"amplitude\":{\"minimum\":2,\"maximum\":20,\"entries\":128}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
